AuthUser class

Custom user model to abstract Firebase's User object.

Constructors

AuthUser(String uid, String? email, bool isAnonymous)

Properties

email String?
The email of the user (can be null for anonymous).
final
hashCode int
The hash code for this object.
no setterinherited
isAnonymous bool
Whether the user signed in anonymously.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uid String
The unique user ID from Firebase.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited